#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
"""Gabbi specific exceptions."""


class GabbiDataLoadError(ValueError):
    """An exception to alert when data streams cannot be loaded."""
    pass


class GabbiFormatError(ValueError):
    """An exception to encapsulate poorly formed test data."""
    pass


class GabbiSyntaxWarning(SyntaxWarning):
    """A warning about syntax that is not desirable."""
    pass
